@@ -73,11 +73,36 @@ class QuerySet(object):
         return handle
 
     def get(self, id, callback, alias=None):
+        '''
+        Gets a single item of the current queryset collection using it's id.
+
+        In order to query a different database, please specify the `alias` of the database to query.
+
+        Usage::
+
+            User.objects.get(user_id, callback=handle_get_user)
+
+            def handle_get_user(instance):
+                # do something with instance
+                # instance is None if user not found
+                pass
+        '''
         self.coll(alias).find_one({
             "_id": id
         }, callback=self.handle_get(callback))
 
     def filter(self, **kwargs):
+        '''
+        Filters a queryset in order to produce a different set of document from subsequent queries.
+
+        Usage::
+
+            User.objects.filter(first_name="Bernardo").filter(last_name="Bernardo").find_all(callback="handle_all")
+            # or
+            User.objects.filter(first_name="Bernardo", starting_year__gt=2010).find_all(callback=handle_all)
+
+        The available filter options are the same as used in MongoEngine.
+        '''
         for field_name, value in kwargs.items():
             if field_name not in self.__klass__._fields:
                 raise ValueError("Invalid filter '%s': Field not found in '%s'." % (field_name, self.__klass__.__name__))
@@ -86,10 +111,29 @@ class QuerySet(object):
         return self
 
     def limit(self, limit):
+        '''
+        Limits the number of documents to return in subsequent queries.
+
+        Usage::
+
+            User.objects.limit(10).find_all(callback="handle_all")  # even if there are 100s of users,
+                                                                    # only first 10 will be returned
+        '''
+
         self._limit = limit
         return self
 
     def order_by(self, field_name, direction=ASCENDING):
+        '''
+        Specified the order to be used when returning documents in subsequent queries.
+
+        Usage::
+
+            from motorengine import DESCENDING  # or ASCENDING
+
+            User.objects.order_by('first_name', direction=DESCENDING).find_all(callback="handle_all")
+        '''
+
         if field_name not in self.__klass__._fields:
             raise ValueError("Invalid order by field '%s': Field not found in '%s'." % (field_name, self.__klass__.__name__))
 
@@ -119,6 +163,20 @@ class QuerySet(object):
         return self.coll(alias).find(self._filters, **find_arguments)
 
     def find_all(self, callback, alias=None):
+        '''
+        Returns a list of items in the current queryset collection that match specified filters (if any).
+
+        In order to query a different database, please specify the `alias` of the database to query.
+
+        Usage::
+
+            User.objects.find_all(callback=handle_all_users)
+
+            def handle_all_users(result):
+                # do something with result
+                # result is None if no users found
+                pass
+        '''
         to_list_arguments = dict(callback=self.handle_find_all(callback))
 
         if self._limit is not None:
@@ -135,4 +193,16 @@ class QuerySet(object):
         return handle
 
     def count(self, callback, alias=None):
+        '''
+        Returns the number of documents in the collection that match the specified filters (if any).
+
+        Usage::
+
+            User.objects.count(callback=handle_count)
+
+            def handle_count(result):
+                # do something with result
+                # result is 0 if no users found
+                pass
+        '''
         self._get_find_cursor(alias=alias).count(callback=self.handle_count(callback))
